#!/usr/local/bin/perl

# Joshua T. Rowe
# 2000-07-05

use Getopt::Long;

my $help = 0;
my $file = "makefile.jmk";
my $sourcedir = $ENV{"SOURCEDIR"};
my $sourcepath = $ENV{"SOURCEPATH"};
my $classdir = $ENV{"CLASSDIR"};
my $classpath = $ENV{"CLASSPATH"};

my %opts = (
    'help!'        => \$help,
    'file=s'       => \$file,
    'sourcedir=s'  => \$sourcedir,
    'sourcepath=s' => \$sourcepath,
    'classdir=s'   => \$classdir,
    'classpath=s'  => \$classpath,
);

GetOptions(%opts);

if ( $help ) {
    showHelp();
    exit();

} else {
    open(OUT, '>' . $file) or die($!);

    writeJMKFile({
        'handle'     => \*OUT,
        'classdir'   => $classdir,
        'sourcedir'  => $sourcedir,
        'sourcepath' => $sourcepath,
        'classpath'  => $classpath,
        'classes'    => [ @ARGV ]
    });

    close(OUT);
}

sub writeJMKFile {
    my %param = %{ shift(@_) };

    my $handle = $param{'handle'};

    print $handle "# This is autogenerated by the script attached below\n";
    print $handle "\n";

    print $handle "javac = " .  quote("javac") . ";\n";

    print $handle "javaflags = " . quote("-d") . " " . 
            quote($param{'classdir'}) .  " " .  quote("-sourcepath") . " " . 
            quote($param{'sourcepath'}) . " " .  quote("-classpath") .  
            quote($param{'classpath'}) . ";\n";

    my @classes = @{ $param{'classes'} };
    for ( my $i = @classes - 1; $i > -1; $i-- ) {
        my $cls = $classes[$i];
        if ( isClass($cls) ) {
            $cls = classToFile($cls);
        }

        $cls =~ s/$classdir(.*)/$1/;

        @{ $param{'classes'} }[$i] = $param{'classdir'} . '/' . $cls;
    }
    
    print $handle "\n";
    print $handle "classes" . " = " . 
            join(" ", @{ quoteList($param{'classes'}) }) . ";\n\n";

    print $handle "\n";
    printTarget($handle, quote($param{'classdir'} . "/%.class"), 
            quote($param{'sourcedir'} . "/%.java"), "    exec javac javaflags ?;");

    printTarget($handle, quote("all"), "classes");

    print $handle "\n";
    printTarget($handle, quote("clean"), "", "    delete classes;");

}

sub printTarget {
    my $handle = shift;
    my $target = shift;
    my $deps = shift;
    my $action = shift;

    print $handle $target . " : " . $deps . " ;\n";

    if ( defined($action) ) {
        print $handle "{\n";
        print $handle $action . "\n";
        print $handle "}\n";
    }
    print $handle "\n";
}

sub quote {
    return '"' . shift(@_) . '"';
}

sub quoteList {
    my @array = @{ shift(@_) };
    for ( my $i = @array - 1; $i > -1; $i-- ) {
        $array[$i] = quote($array[$i]);
    }

    return \@array;
}

sub showHelp {
#FIXME
    return;

    print "\n";

    my @opts = (
        "--help",
        "--class-dir <classdir>",
    );

    my $maxLen = 0;
    print "Usage: EnumTool ";
    foreach ( @opts ) {
        my $str = "[ $_ ] ";
        print $str;

        my $l = length($_);
        if ( $l > $maxLen ) {
            $maxLen = $l;
        }
    }

    print "\n";

    my $frontSize = $maxLen + 4;
    
    my $sp = padToLength($frontSize, "");

    print padToLength($frontSize, "--help");
    print "Prints this message";
    print "\n";

    print "\n";

    print padToLength($frontSize, "--sync-classes <classes>");

    print "\n";

    print "\n";
}

sub padToLength {
    my ( $len, $str ) = @_;

    my $newStr = $str;
    while ( length($newStr) < $len ) {
        $newStr = $newStr . " ";
    }

    return $newStr;
}

sub isClass {
    my $str = shift;
    return ! ( $str =~ m/\.class$/ );
}

sub classToFile {
    my $class = shift;

    my $file = $class;
    $file =~ s/\./\//g;

    return $file . ".class";
}

