/*
 *  AbstractOptionsMethod.java
 *  Copyright (C) 1999,2000  Joshua T. Rowe
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *  To contact the author:
 *  email : jrowe3@home.com
 *  web   : http://jrowe.dhs.org/~jrowe/
 */

package jrowe.getopt;

/**
 * An abstract <code>OptionMethod</code> object that stores an argument.
 * <p>
 *
 * This is used when an <code>Option</code> takes an argument.
 * <p>
 *
 * @author Joshua T. Rowe
 * @version 1.1  MAR 10 2000  Moved from package org.jrowe.getopt to
 *          jrowe.getopt.
 * @version 1.0  JAN 23 2000  Initial documented version.  Preparation for
 *          release 0.1
 * @JDKVersion 1.2
 */
abstract public class AbstractOptionMethod extends Object 
        implements OptionMethod {

    /**
     * The <code>Option</code> object to which this belongs.
     *
     * @serial
     */
    private Option option;

    /**
     * Creates an <code>OptionMethod</code> with the default properties.
     */
    public AbstractOptionMethod() {
        this(null);
    }

    /**
     * Creates an <code>OptionMethod</code> with the given properties.
     *
     * @param option the <code>Option</code> to which this functionality
     *        belongs.
     */
    public AbstractOptionMethod(Option option) {
        this.option = option;
    }

    /**
     * Sets the <code>Option</code> to which this functionality belongs.
     *
     * @param option the <code>Option</code> to which this functionality
     *        belongs.
     */
    protected void setOption(Option option) {
        this.option = option;
    }

    /**
     * Returns the <code>Option</code> to which this functionality belongs.
     *
     * @return the <code>Option</code> to which this functionality belongs.
     */
    public Option getOption() {
        return option;
    }

    /**
     * The method which contains the said functionality.
    public void run() {
    }
     */

}

