/*
 *  GetOptions.java
 *  Copyright (C) 1999,2000  Joshua T. Rowe
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *  To contact the author:
 *  email : jrowe3@home.com
 *  web   : http://members.home.com/jrowe3/
 */

package jrowe.getopt;

import java.util.Iterator;
import java.util.List;

/**
 * An object that stores a list of <code>Option</code> objects and then
 * parse command line arguments using them.
 * <p>
 *
 * @author Joshua T. Rowe
 * @version 1.3  03 MAY 2000  Added more constants
 * @version 1.2  MAR 10 2000  Moved from package org.jrowe.getopt to
 *          jrowe.getopt.
 * @version 1.1  JAN 23 2000  Preparation for release 0.1
 * @version 1.0  AUG 27 1999  Initial documented version.
 */
public interface GetOptions {

    /**
     * Indicates the for overal setup of the options.
     *
     * @since 1.3
     * @serial
     */
    public static final int OPTION_SETUP_GNU = 0;

    /**
     * Indicates the for overal setup of the options.
     *
     * @since 1.3
     * @serial
     */
    public static final int OPTION_SETUP_POSIX = 1;

    /**
     * Indicates the for overal setup of the options.
     *
     * @since 1.3
     * @serial
     */
    public static final int OPTION_SETUP_DOS = 2;

    /**
     * Adds an <code>Option</code> to the list of parseable options.
     *
     * @param option The <code>Option</code> to add.
     */
    public void add(Option option);

    /**
     * Removes an <code>Option</code> from the list of parseable options.
     *
     * @param option The <code>Option</code> to remove.
     */
    public void remove(Option option);

    /**
     * Removes an <code>Option</code> from the list of parseable options.
     *
     * @param optionName The name of the <code>Option</code> to remove.
     * @param The <code>Option</code> which was removed.  If this object does
     *        not contain an </code>Option</code> by that name, then 
     *        <code>null</code> will be returned.
     */
    public Option remove(String optionName);

    /**
     * Returns an <code>Option</code> from the list of parseable options.
     *
     * @param optionName The name of the <code>Option</code> to return.
     * @param The <code>Option</code>.  If this object does not contain an
     *        </code>Option</code> by that name, then <code>null</code> will be
     *        returned.
     */
    public Option get(String optionName);

    /**
     * Returns an <code>Iterator</code> object which will iterate over all
     * of the <code>Options</code> contained by this object.
     *
     * @return An <code>Iterator</code>
     */
    public Iterator iterator();

    /**
     * Sets the arguments from the command line.
     * <p>
     *
     * The options are processed immediately.
     *
     * @param args The arguments from the command line.
     */
    public void setArgs(String[] args) throws OptionException;

    /**
     * Returns the program arguments.
     *
     * @return The program arguments.
     */
    public List getProgramArgs();

}

