/*
 *  OptionException.java
 *  Copyright (C) 1999,2000  Joshua T. Rowe
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *  To contact the author:
 *  email : jrowe3@home.com
 *  web   : http://jrowe.dhs.org/~jrowe/
 */

package jrowe.getopt;

/**
 * An <code>Exception</code> representing when there has been an invalid
 * option detected in the command line arguments.
 *
 * @author Joshua T. Rowe
 * @version 1.1  MAR 10 2000  Moved from package org.jrowe.getopt to
 *          jrowe.getopt.
 * @version 1.0  JAN 23  Intial documented version.  Preparation for 
 *          release 0.1
 */
public class OptionException extends RuntimeException {

    /**
     * A constant representing no error.
     *
     * @serial
     */
    public static final int NO_ERROR = 0;

    /**
     * A constant representing an uknown option.
     *
     * @serial
     */
    public static final int UNKNOWN_OPTION = 1;

    /**
     * A constant representing a missing argument for an option.
     *
     * @serial
     */
    public static final int MISSING_ARGUMENT = 2;

    /**
     * A constant representing an incorrectly formatted argument for an option.
     *
     * @serial
     */
    public static final int MALFORMED_ARGUMENT = 3;

    /**
     * A constant representing an uknown error.
     *
     * @serial
     */
    public static final int UNKNOWN_ERROR = 255;

    /**
     * Contains the error code.
     *
     * @serial
     */
    private int errorCode;
    
    /**
     * Creates a new <code>OptionException</code> with the default properties.
     */
    public OptionException() {
        this("Uknown Option Exception", UNKNOWN_ERROR);
    }

    /**
     * Creates a new <code>OptionException</code> with the given properties.
     */
    public OptionException(String s, int errorCode) {
        super(s);
        setErrorCode(errorCode);
    }

    /**
     * Sets the error code.
     *
     * @param errorCode the error code
     */
    protected void setErrorCode(int errorCode) {
        this.errorCode = errorCode;
    }

    /**
     * Returns the error code.
     *
     * @return the error code
     */
    public int getErrorCode() {
        return errorCode;
    }

}

