/*
 *  ProjectTestCase.java
 *  Copyright (C) 2000  Joshua T. Rowe
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *  To contact the author:
 *  email : jrowe3@home.com
 *  web   : http://jrowe.dhs.org/~jrowe/
 */

package jrowe.test;

import java.lang.reflect.Constructor;
import java.lang.reflect.Method;
import java.lang.reflect.InvocationTargetException;

import java.util.Arrays;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

import jrowe.util.ClassUtil;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 * @author Joshua T. Rowe
 * @version 1.0  11 MAY 2000  Intial version.
 */
public class ProjectTestCase extends TestSuite {

    private static final String[] TEST_CLASS_NAMES = {
        "jrowe.test.util.ClassUtilTest"
    };

    private List tests;

    public ProjectTestCase(String projectName) {
        super(projectName);

        tests = createTestList();
        addTests(tests);
    }

    protected static List createDefaultList() {
        return new LinkedList();
    }

    protected List createTestList() {
        List list = createDefaultList();

        list.addAll(Arrays.asList(TEST_CLASS_NAMES));

        return list;
    }

    public List getTests() {
        return tests;
    }

    public void addTests(ProjectTestCase testCase) {
        if ( testCase == null ) {
            throw new IllegalArgumentException("testCase cannot be null");
        }

        List l = testCase.getTests();
        if ( l != null ) {
            addTests(testCase.getTests());

        } else {
            System.err.println(getClass().getName() + ".addTests(" +
                    ProjectTestCase.class.getName() + "):testCase had " +
                    "no tests: testCase=\"" + testCase.toString() + "\"");
        }
    }

    protected void addTests(List tests) {
        if ( tests == null ) {
            throw new IllegalArgumentException("tests cannot be null");
        }

        Iterator it = tests.iterator();
        while ( it.hasNext() ) {
            addTest(it.next().toString());
        }
    }

    protected void addTest(String className) {
        try {
            Class cls = Class.forName(className);
            Test suite = new TestSuite(cls);

            if ( suite != null ) {
                addTest(suite);

            } else {
                System.err.println("suite is null");
            }

        } catch (ClassNotFoundException e) {
            e.printStackTrace();
        }
    }

    public static Test createSelf(Class cls, String name) {
        Object self = null;

        try {
            Constructor constructor = cls.getConstructor(
                    new Class[] { String.class });
            self = constructor.newInstance(new Object[] { name });

        } catch (SecurityException e) {
            e.printStackTrace();

        } catch (NoSuchMethodException e) {
            e.printStackTrace();

        } catch (InstantiationException e) {
            e.printStackTrace();

        } catch (IllegalAccessException e) {
            e.printStackTrace();

        } catch (IllegalArgumentException e) {
            e.printStackTrace();

        } catch (InvocationTargetException e) {
            e.printStackTrace();
        }

        return (Test) self;
    }

//    public static Test suite(Class cls) {
//        Test suite = createSelf(cls, "ProjectTestCase");
//
//        return suite;
//    }

    public static Test suite() {
        return new ProjectTestCase("ProjectTestCase");
    }

    public static void main(String[] args) {
        if ( args.length > 0 ) {
            new Tester().runSuite(args[0]);

        } else {
            new Tester().runSuite(ProjectTestCase.suite());
        }
    }

}

