/*
 *  Driver.java
 *  Copyright (C) 1999,2000  Joshua T. Rowe
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *  To contact the author:
 *  email : jrowe3@home.com
 *  web   : http://jrowe.dhs.org/~jrowe/
 */

package jrowe.test.getopt;

import java.io.File;

import java.util.Iterator;

import jrowe.getopt.AbstractOptionMethod;
import jrowe.getopt.GetOptions;
import jrowe.getopt.DefaultGetOptions;
import jrowe.getopt.DefaultOption;
import jrowe.getopt.Option;
import jrowe.getopt.OptionException;

/**
 * @author Joshua T. Rowe
 * @version 1.1  MAY 08 2000  Inital documented version.  Moved from
 *          org.jrowe.getopt to jrowe.test.getopt
 * @version 1.0  MAR 10 2000  Inital documented version.  Moved from
 *          org.jrowe.getopt to jrowe.test.getopt
 */
public final class Driver {

    private GetOptions getOptions;

    public Driver() {
        super();
        getOptions = new DefaultGetOptions();
    }
   
    private void testSetup1() {
        Option option = new DefaultOption();
        option.setName("version");
        option.setChar('v');
        option.setMethod(new AbstractOptionMethod() {
            public void run() {
                System.out.println("This is Driver version 1.0");
            }
        });
        getOptions.add(option);

        option = new DefaultOption();
        option.setName("multtest");
        option.setChar('m');
//        option.setMaxInstances(-1);
        option.setMethod(new AbstractOptionMethod() {
            public void run() {
                System.out.println("This is multtest");
            }
        });
        getOptions.add(option);

        option = new DefaultOption();
        option.setName("file");
        option.setChar('f');
        option.setArgType(Option.SCALAR_ARG);
        option.setMethod(new AbstractOptionMethod(option) {
            public void run() {
                File f = new File((String) getOption().getArg());
                if ( f != null ) {
                    System.out.println("file " + f + " exists: " + f.exists());
                } else {
                    System.out.println("arg for file is null");
                }
            }
        });
        getOptions.add(option);
    }
    
    public static void main(String[] args) {
        System.out.println("Begin Driver");

        Driver driver = new Driver();

        driver.testSetup1();

        driver.getOptions.setArgs(args);

        System.out.println("");
        System.out.println("    Begin Program Args");
        Iterator it = driver.getOptions.getProgramArgs().iterator();
        while ( it.hasNext() ) {
            System.out.println(it.next().toString());
        }
        System.out.println("    End Program Args");

        System.out.println("End Driver");
    }
    
}

