/*
 *  ClassUtil.java
 *  Copyright (C) 2000  Joshua T. Rowe
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *  To contact the author:
 *  email : jrowe3@home.com
 *  web   : http://jrowe.dhs.org/~jrowe/
 */

package jrowe.util;

import java.io.IOException;
import java.io.LineNumberReader;
import java.io.PrintWriter;
import java.io.StringReader;
import java.io.StringWriter;

import java.util.LinkedList;
import java.util.List;

/**
 * Cool trick to do static stuff without static ref.
 *
 * @version 1.0  MAR 09 2000  Initial version
 */
public class ClassUtil {

    /**
     * Creates a <code>ClassUtil</code> object.
     *
     * <p>
     * <strong>
     * NOTE:<br>
     * This is private to prevent the creation of instances of this class.
     * </strong>
     * </p>
     */
    private ClassUtil() {
        super();
    }

    /**
     * Returns the <code>Class</code> of the caller of this method.
     *
     * @return the <code>Class</code> of the caller of this method.
     */
    public static Class getSelf() {
        return getSelf(1);
    }

    /**
     * Returns the <code>Class</code> of the caller of this method.
     *
     * @return the <code>Class</code> of the caller of this method.
     */
    public static Class getSelf(int level) {
        Class selfClass = Object.class;

        try {
            selfClass = Class.forName(getAll(3 + level)[0]);

        } catch (ClassNotFoundException e) {
            e.printStackTrace();
        }

        return selfClass;
    }

    public static String[] splitPackageAndClass(String str) {
        return null;
    }

    public static String getClassName() {
        return getAll(1)[0];
    }

    public static String getMethodName() {
        return getAll(1)[1];
    }

    public static String[] getAll() {
        return getAll(0);
    }

    private static String[] getAll(int level) {
        String[] all = new String[] { "", "" };

//FIXME change to return String[] { <class>, <method> }
        StringWriter sw = new StringWriter();
        new Exception().printStackTrace(new PrintWriter(sw));

//TEMP
//        new Exception().printStackTrace();

        LineNumberReader lnr = new LineNumberReader(new StringReader(
                sw.getBuffer().toString()));

        String line = null;

        boolean error = false;

        /*
         * the third line of the stack trace contains the class & method that
         * that directly called this method.
         */
        final int TARGET_LINE = 3 + level;
        final char END_OF_METHOD_CHAR = '(';
        final char BEGIN_OF_METHOD_CHAR = '.';
        final String STACK_PREFIX = "at ";

        try {
            while ( ( ( line = lnr.readLine() ) != null ) && 
                    ( lnr.getLineNumber() < TARGET_LINE ) ) {}

        } catch (IOException e) {
            e.printStackTrace();
            error = true;
        }

        if ( ( ! error ) && ( lnr.getLineNumber() == TARGET_LINE ) ) {
            all = parseStackTraceLine(line);
        }

        return all;
    }

    public static String[] parseStackTraceLine(String line) {
//    System.out.println("line=" + line);

//FIXME : add range checking
        String[] all = new String[2];

        final char END_OF_METHOD_CHAR = '(';
        final char BEGIN_OF_METHOD_CHAR = '.';
        final String STACK_PREFIX = "at ";

        int i2 = line.indexOf(END_OF_METHOD_CHAR);
        int i1 = line.lastIndexOf(BEGIN_OF_METHOD_CHAR, i2);
        int i3 = line.indexOf(STACK_PREFIX);

        all[0] = line.substring(i3 + STACK_PREFIX.length(), i1);
        all[1] = line.substring(i1 + 1, i2);

        return all;
    }

    public static final boolean selfTest() {
        System.out.println("jrowe.util.ClassUtil.selfTest() : begin");

        boolean selfTestPass = true;
        boolean pass = true;

        try {
            pass = "selfTest".equals(getMethodName());
            System.out.println("test : getMethodName() : " +
                    (( pass ) ? "pass" : "fail"));

        } catch (Throwable t) {
            t.printStackTrace();
            pass = false;
        }
        selfTestPass = selfTestPass && pass;

        try {
            pass = "jrowe.util.ClassUtil".equals(getClassName());
            System.out.println("test : getClassName() : " +
                    (( pass ) ? "pass" : "fail"));

        } catch (Throwable t) {
            t.printStackTrace();
            pass = false;
        }
        selfTestPass = selfTestPass && pass;

        try {
            pass = jrowe.util.ClassUtil.class.equals(getSelf());
            System.out.println("test : getSelf() : " +
                    (( pass ) ? "pass" : "fail"));

        } catch (Throwable t) {
            t.printStackTrace();
            pass = false;
        }
        selfTestPass = selfTestPass && pass;

        System.out.println();

        System.out.println("selfTest result : " +
                (( selfTestPass ) ? "pass" : "fail"));

        System.out.println("jrowe.util.ClassUtil.selfTest() : end");

        return selfTestPass;
    }

    public static final void main(String[] args) {
        selfTest();
    }

}

