/*
 *  TokenIterator.java
 *  Copyright (C) 2000  Joshua T. Rowe
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *  To contact the author:
 *  email : jrowe3@home.com
 *  web   : http://jrowe.dhs.org/~jrowe/
 */

package jrowe.util;

import java.util.Iterator;
import java.util.Set;

/**
 * @author Joshua T. Rowe
 * @version 1.1  MAR 11 2000  Moved from no package to jrowe.util
 * @version 1.0  FEB 10 2000  Initial version.
 */
public interface TokenIterator extends Iterator {

    /**
     * Returns the token types that could potentially be returned by this
     * <code>TokenIterator</code>.
     *
     * @return a <code>Set</code> containing the potential token types.  The
     *         actual class of the elements of the set are implementation
     *         dependant.
     */
    public Set getTokenTypes();

    /**
     * Returns the type of the current token.
     * The current token being the token retreived by calling
     * <code>next()</code>.
     *
     * @return the type of the current token.
     *
     * @exception java.lang.IllegalStateException 
     *            thrown if the <code>next</code> method has
     *            not yet been called, or the <code>remove</code> method has
     *            already been called after the last call to the
     *            <code>next</code> method.
     */
    public Object getType();

    /**
     * This is an unsupported method in a <code>TokenIterator</code> object.
     * 
     * @exception java.lang.UnsupportedOperationException always thrown in
     *            this implementation.
     */
    public void remove();

}

